==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/HeaderRowSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { HeaderRowSeparatorDescription } from "./HeaderRowSeparatorDescription";
/**
 * @hidden
 */
var HeaderRowSeparatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(HeaderRowSeparatorDescriptionMetadata, _super);
    function HeaderRowSeparatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HeaderRowSeparatorDescriptionMetadata.b = function (a) {
        if (HeaderRowSeparatorDescriptionMetadata.a == null) {
            HeaderRowSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            HeaderRowSeparatorDescriptionMetadata.c(HeaderRowSeparatorDescriptionMetadata.a);
        }
        if (a.g(HeaderRowSeparatorDescriptionMetadata.a)) {
            return;
        }
        a.s(HeaderRowSeparatorDescriptionMetadata.a);
    };
    HeaderRowSeparatorDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
    };
    HeaderRowSeparatorDescriptionMetadata.d = function (a) {
        HeaderRowSeparatorDescriptionMetadata.b(a);
        a.u("HeaderRowSeparator", function () { return new HeaderRowSeparatorDescription(); });
        a.t("HeaderRowSeparator", HeaderRowSeparatorDescriptionMetadata.a);
    };
    HeaderRowSeparatorDescriptionMetadata.$t = markType(HeaderRowSeparatorDescriptionMetadata, 'HeaderRowSeparatorDescriptionMetadata');
    HeaderRowSeparatorDescriptionMetadata.a = null;
    return HeaderRowSeparatorDescriptionMetadata;
}(Base));
export { HeaderRowSeparatorDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/HeaderRowSeparatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { HeaderRowSeparatorDescription } from "./HeaderRowSeparatorDescription";
/**
 * @hidden
 */
var HeaderRowSeparatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(HeaderRowSeparatorDescriptionMetadata, _super);
    function HeaderRowSeparatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    HeaderRowSeparatorDescriptionMetadata.b = function (a) {
        if (HeaderRowSeparatorDescriptionMetadata.a == null) {
            HeaderRowSeparatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            HeaderRowSeparatorDescriptionMetadata.c(HeaderRowSeparatorDescriptionMetadata.a);
        }
        if (a.j(HeaderRowSeparatorDescriptionMetadata.a)) {
            return;
        }
        a.y(HeaderRowSeparatorDescriptionMetadata.a);
    };
    HeaderRowSeparatorDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
    };
    HeaderRowSeparatorDescriptionMetadata.d = function (a) {
        HeaderRowSeparatorDescriptionMetadata.b(a);
        a.aa("HeaderRowSeparator", function () { return new HeaderRowSeparatorDescription(); });
        a.z("HeaderRowSeparator", HeaderRowSeparatorDescriptionMetadata.a);
    };
    HeaderRowSeparatorDescriptionMetadata.$t = markType(HeaderRowSeparatorDescriptionMetadata, 'HeaderRowSeparatorDescriptionMetadata');
    HeaderRowSeparatorDescriptionMetadata.a = null;
    return HeaderRowSeparatorDescriptionMetadata;
}(Base));
export { HeaderRowSeparatorDescriptionMetadata };
